==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QSGNinePatchNode_shell.h <==
#ifndef QSGNINEPATCHNODE_SHELL_H
#define QSGNINEPATCHNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qsgninepatchnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qvectornd.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QSGNinePatchNode_shell : public QSGNinePatchNode, public QtJambiShellInterface
{
public:
    QSGNinePatchNode_shell();
    ~QSGNinePatchNode_shell() override;

    bool isSubtreeBlocked() const override;
    void preprocess() override;
    void setBounds(const QRectF& bounds0) override;
    void setDevicePixelRatio(qreal ratio0) override;
    void setPadding(qreal left0, qreal top1, qreal right2, qreal bottom3) override;
    void setTexture(QSGTexture* texture0) override;
    void update() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGNinePatchNode_access : public QSGNinePatchNode
{
    void __qt_setBounds_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID bounds0);
    void __qt_setDevicePixelRatio_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble ratio0);
    void __qt_setPadding_qreal_qreal_qreal_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble left0, jdouble top1, jdouble right2, jdouble bottom3);
    void __qt_setTexture_QSGTexture_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID texture0);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSGNINEPATCHNODE_SHELL_H

==> qtjambi-quick-debuginfo-macos-6.5.7.jar: sources/QtJambiQuick/QSGNinePatchNode_shell.h <==
#ifndef QSGNINEPATCHNODE_SHELL_H
#define QSGNINEPATCHNODE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgninepatchnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qrect.h>
#include <QtGui/qmatrix4x4.h>
#include <QtGui/qvectornd.h>
#include <QtQuick/qsggeometry.h>
#include <QtQuick/qsgmaterial.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QSGNinePatchNode_shell : public QSGNinePatchNode, public QtJambiShellInterface
{
public:
    QSGNinePatchNode_shell();
    ~QSGNinePatchNode_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QSGNinePatchNode_oshell;
};


class QSGNinePatchNode_oshell : public QSGNinePatchNode_shell
{
public:
    using QSGNinePatchNode_shell::QSGNinePatchNode_shell;
    bool isSubtreeBlocked() const override;
    void preprocess() override;
    void setBounds(const QRectF& bounds0) override;
    void setDevicePixelRatio(qreal ratio0) override;
    void setPadding(qreal left0, qreal top1, qreal right2, qreal bottom3) override;
    void setTexture(QSGTexture* texture0) override;
    void update() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGNinePatchNode_access : public QSGNinePatchNode
{
    void __qt_setBounds_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID bounds0);
    void __qt_setDevicePixelRatio_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble ratio0);
    void __qt_setPadding_qreal_qreal_qreal_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble left0, jdouble top1, jdouble right2, jdouble bottom3);
    void __qt_setTexture_QSGTexture_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID texture0);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSGNINEPATCHNODE_SHELL_H
